@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- $Id: battstat_applet.c 10289 2007-07-17 06:20:57Z jhaitsma $
+ $Id: battstat_applet.c 10756 2008-03-15 22:45:30Z callum $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -41,8 +41,6 @@
 
 #include <libgnomeui/libgnomeui.h>
 
-#include <glade/glade.h>
-
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 
@@ -321,7 +319,6 @@ static_global_initialisation (int no_hal, ProgressData *battstat)
 
   allocate_battery_colours();
   initialise_global_pixmaps();
-  glade_init();
   err = power_management_initialise (no_hal, status_change_callback);
 
   return err;
