@@ -49,33 +49,7 @@ static gboolean	cb_button_release			(GtkWidget *widget,
 
 static GtkWindowClass *parent_class = NULL;
 
-GType
-gnome_volume_applet_dock_get_type (void)
-{
-  static GType gnome_volume_applet_dock_type = 0;
-
-  if (!gnome_volume_applet_dock_type) {
-    static const GTypeInfo gnome_volume_applet_dock_info = {
-      sizeof (GnomeVolumeAppletDockClass),
-      NULL,
-      NULL,
-      (GClassInitFunc) gnome_volume_applet_dock_class_init,
-      NULL,
-      NULL,
-      sizeof (GnomeVolumeAppletDock),
-      0,
-      (GInstanceInitFunc) gnome_volume_applet_dock_init,
-      NULL
-    };
-
-    gnome_volume_applet_dock_type =
-	g_type_register_static (GTK_TYPE_WINDOW, 
-				"GnomeVolumeAppletDock",
-				&gnome_volume_applet_dock_info, 0);
-  }
-
-  return gnome_volume_applet_dock_type;
-}
+G_DEFINE_TYPE (GnomeVolumeAppletDock, gnome_volume_applet_dock, GTK_TYPE_WINDOW)
 
 static void
 gnome_volume_applet_dock_class_init (GnomeVolumeAppletDockClass *klass)
@@ -106,11 +80,13 @@ gnome_volume_applet_dock_new (GtkOrientation orientation)
     GtkWidget * (* sfunc) (GtkAdjustment *adj);
     gint sw, sh;
   } magic[2] = {
-    { 3, 1, { 0, 1, 2 }, { 0, 0, 0 }, gtk_hscale_new, 100, -1 },
+    { 3, 1, { 2, 1, 0 }, { 0, 0, 0 }, gtk_hscale_new, 100, -1 },
     { 1, 3, { 0, 0, 0 }, { 0, 1, 2 }, gtk_vscale_new, -1, 100 }
   };
 
-  dock = g_object_new (GNOME_VOLUME_APPLET_TYPE_DOCK, NULL);
+  dock = g_object_new (GNOME_VOLUME_APPLET_TYPE_DOCK,
+		       "type-hint", GDK_WINDOW_TYPE_HINT_UTILITY,
+		       NULL);
   dock->orientation = orientation;
   GTK_WINDOW (dock)->type = GTK_WINDOW_POPUP;
   GTK_WIDGET_UNSET_FLAGS (dock, GTK_TOPLEVEL);
@@ -141,7 +117,8 @@ gnome_volume_applet_dock_new (GtkOrientation orientation)
 			       magic[orientation].sw,
 			       magic[orientation].sh);
   gtk_scale_set_draw_value (GTK_SCALE (scale), FALSE);
-  gtk_range_set_inverted (dock->scale, TRUE);
+  if (orientation == GTK_ORIENTATION_VERTICAL)
+    gtk_range_set_inverted (dock->scale, TRUE);
   gtk_table_attach_defaults (GTK_TABLE (table), scale,
 			     magic[orientation].x[1],
 			     magic[orientation].x[1] + 1,
